Welcome to inept's documentation!
=================================

An "**in**\ teractive **e**\ ditable o\ **pt**\ ions" library for handling complex option hierarchies
from multiple sources (script, CLI, config files, ...).

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   install
   quick-start
   tutorials/index

.. toctree::
   :maxdepth: 2
   :caption: Developer Guide

   contributing
   roadmap

.. toctree::
   :maxdepth: 1
   :caption: Reference API

   api/inept


* :ref:`genindex`
